@@ -84,7 +84,6 @@ class BreakQueue:
         self.__current_break = None
         self.__current_long = 0
         self.__current_short = 0
-        self.__shorts_taken = 0
         self.__short_break_time = config.get('short_break_interval')
         self.__long_break_time = config.get('long_break_interval')
         self.__is_random_order = config.get('random_order')
@@ -113,19 +112,43 @@ class BreakQueue:
                     while brk != current_break and brk.name != last_break:
                         brk = self.next()
 
-    def get_break(self):
+    def get_break(self, break_type = None):
         if self.__current_break is None:
             self.__current_break = self.next()
-        return self.__current_break
+
+        if break_type is None or self.__current_break.type == break_type:
+            return self.__current_break
+
+        if break_type == BreakType.LONG_BREAK:
+            if self.__long_queue is None:
+                return None;
+            return self.__long_queue[self.__current_long]
+
+        if self.__short_queue is None:
+            return None;
+        return self.__short_queue[self.__current_short]
 
     def is_long_break(self):
         return self.__current_break is not None and self.__current_break.type == BreakType.LONG_BREAK
 
-    def next(self):
+    def next(self, break_type = None):
         break_obj = None
         shorts = self.__short_queue
         longs  = self.__long_queue
 
+        # Reset break that has just ended
+        if self.is_long_break():
+            self.__current_break.time = self.__long_break_time
+            if self.__current_long == 0 and self.__is_random_order:
+                # Shuffle queue
+                self.__build_longs()
+        elif self.__current_break:
+            # Reduce the break time from the next long break (default)
+            if longs:
+                longs[self.__current_long].time -= shorts[self.__current_short].time
+            if self.__current_short == 0 and self.__is_random_order:
+                self.__build_shorts()
+
         if self.is_empty():
             return None
 
@@ -133,27 +156,11 @@ class BreakQueue:
             break_obj = self.__next_long()
         elif longs is None:
             break_obj = self.__next_short()
-        elif longs[self.__current_long].time <= shorts[self.__current_short].time:
+        elif break_type == BreakType.LONG_BREAK or longs[self.__current_long].time <= shorts[self.__current_short].time:
             break_obj = self.__next_long()
         else:
             break_obj = self.__next_short()
 
-        # Shorts and longs exist -> set cycle on every long
-        if break_obj.type == BreakType.LONG_BREAK:
-            self.context['new_cycle'] = True
-            self.__shorts_taken = 0
-        # Only shorts exist -> set cycle when enough short breaks pass
-        elif self.__shorts_taken  == self.__cycle_len:
-            self.context['new_cycle'] = True
-            self.__shorts_taken = 0
-        else:
-            self.context['new_cycle'] = False
-
-        if self.__current_break is not None:
-            # Reset the time of long breaks
-            if self.__current_break.type == BreakType.LONG_BREAK:
-                self.__current_break.time = self.__long_break_time
-
         self.__current_break = break_obj
         self.context['session']['break'] = self.__current_break.name
 
@@ -162,30 +169,30 @@ class BreakQueue:
     def reset(self):
         for break_object in self.__short_queue:
             break_object.time = self.__short_break_time
-        
+
         for break_object in self.__long_queue:
             break_object.time = self.__long_break_time
 
-    def is_empty(self):
-        return self.__short_queue is None and self.__long_queue is None
+    def is_empty(self, break_type = None):
+        """
+        Check if the given break type is empty or not. If the break_type is None, check for both short and long breaks.
+        """
+        if break_type == BreakType.SHORT_BREAK:
+            return self.__short_queue is None
+        elif break_type == BreakType.LONG_BREAK:
+            return self.__long_queue is None
+        else:
+            return self.__short_queue is None and self.__long_queue is None
 
     def __next_short(self):
         longs  = self.__long_queue
         shorts = self.__short_queue
         break_obj = shorts[self.__current_short]
         self.context['break_type'] = 'short'
-        # Reduce the break time from the next long break (default)
-        if longs:
-            longs[self.__current_long].time -= shorts[self.__current_short].time
 
         # Update the index to next
         self.__current_short = (self.__current_short + 1) % len(shorts)
 
-        # Shuffle queue
-        if self.__current_short == 0 and self.__is_random_order:
-            self.__build_shorts()
-
-        self.__shorts_taken += 1
         return break_obj
 
     def __next_long(self):
@@ -196,10 +203,6 @@ class BreakQueue:
         # Update the index to next
         self.__current_long = (self.__current_long + 1) % len(longs)
 
-        # Shuffle queue
-        if self.__current_long == 0 and self.__is_random_order:
-            self.__build_longs()
-
         return break_obj
 
     def __build_queue(self, break_type, break_configs, break_time, break_duration):
@@ -255,12 +258,13 @@ class State(Enum):
     """
     Possible states of Safe Eyes.
     """
-    START = 0,
-    WAITING = 1,
-    PRE_BREAK = 2,
-    BREAK = 3,
-    STOPPED = 4,
-    QUIT = 5
+    START = 0,       # Starting scheduler
+    WAITING = 1,     # User is working (waiting for next break)
+    PRE_BREAK = 2,   # Preparing for break
+    BREAK = 3,       # Break
+    STOPPED = 4,     # Disabled
+    QUIT = 5,        # Quitting
+    RESTING = 6      # Resting (natural break)
 
 
 class EventHook:
@@ -304,6 +308,8 @@ class Config:
         # self.__force_upgrade = ['long_breaks', 'short_breaks']
 
         if init:
+            # if create_startup_entry finds a broken autostart symlink, it will repair it
+            utility.create_startup_entry(force=False)
             if self.__user_config is None:
                 utility.initialize_safeeyes()
                 self.__user_config = self.__system_config
