@@ -40,7 +40,7 @@ from safeeyes.ui.settings_dialog import SettingsDialog
 gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 
-SAFE_EYES_VERSION = "2.1.5"
+SAFE_EYES_VERSION = "2.1.9"
 
 
 class SafeEyes:
@@ -71,8 +71,8 @@ class SafeEyes:
             self.show_about)
         self.context['api']['enable_safeeyes'] = lambda next_break_time=-1, reset_breaks=False: \
             utility.execute_main_thread(self.enable_safeeyes, next_break_time, reset_breaks)
-        self.context['api']['disable_safeeyes'] = lambda status: utility.execute_main_thread(
-            self.disable_safeeyes, status)
+        self.context['api']['disable_safeeyes'] = lambda status=None, is_resting=False: utility.execute_main_thread(
+            self.disable_safeeyes, status, is_resting)
         self.context['api']['status'] = self.status
         self.context['api']['quit'] = lambda: utility.execute_main_thread(
             self.quit)
@@ -93,10 +93,10 @@ class SafeEyes:
         self.safe_eyes_core.on_stop_break += self.stop_break
         self.safe_eyes_core.on_update_next_break += self.update_next_break
         self.safe_eyes_core.initialize(self.config)
-        self.context['api']['take_break'] = lambda: utility.execute_main_thread(
-            self.safe_eyes_core.take_break)
+        self.context['api']['take_break'] = self.take_break
         self.context['api']['has_breaks'] = self.safe_eyes_core.has_breaks
         self.context['api']['postpone'] = self.safe_eyes_core.postpone
+        self.context['api']['get_break_time'] = self.safe_eyes_core.get_break_time
         self.plugins_manager.init(self.context, self.config)
         atexit.register(self.persist_session)
 
@@ -158,7 +158,7 @@ class SafeEyes:
             if self.active:
                 logging.info("Stop Safe Eyes due to system suspend")
                 self.plugins_manager.stop()
-                self.safe_eyes_core.stop()
+                self.safe_eyes_core.stop(True)
         else:
             # Resume from sleep
             if self.active and self.safe_eyes_core.has_breaks():
@@ -239,14 +239,14 @@ class SafeEyes:
             self.safe_eyes_core.start(scheduled_next_break_time, reset_breaks)
             self.plugins_manager.start()
 
-    def disable_safeeyes(self, status=None):
+    def disable_safeeyes(self, status=None, is_resting = False):
         """
         Listen to tray icon disable action and send the signal to core.
         """
         if self.active:
             self.active = False
             self.plugins_manager.stop()
-            self.safe_eyes_core.stop()
+            self.safe_eyes_core.stop(is_resting)
             if status is None:
                 status = _('Disabled until restart')
             self._status = status
@@ -295,11 +295,11 @@ class SafeEyes:
         self.plugins_manager.stop_break()
         return True
 
-    def take_break(self):
+    def take_break(self, break_type = None):
         """
         Take a break now.
         """
-        self.safe_eyes_core.take_break()
+        utility.execute_main_thread(self.safe_eyes_core.take_break, break_type)
 
     def status(self):
         """
