@@ -21,7 +21,6 @@ This module contains utility functions for Safe Eyes and its plugins.
 """
 
 import errno
-import imp
 import inspect
 import importlib
 import json
@@ -51,10 +50,11 @@ BIN_DIRECTORY = os.path.dirname(os.path.realpath(__file__))
 HOME_DIRECTORY = os.environ.get('HOME') or os.path.expanduser('~')
 CONFIG_DIRECTORY = os.path.join(os.environ.get(
     'XDG_CONFIG_HOME') or os.path.join(HOME_DIRECTORY, '.config'), 'safeeyes')
+STYLE_SHEET_DIRECTORY = os.path.join(CONFIG_DIRECTORY, 'style')
 CONFIG_FILE_PATH = os.path.join(CONFIG_DIRECTORY, 'safeeyes.json')
 CONFIG_RESOURCE = os.path.join(CONFIG_DIRECTORY, 'resource')
 SESSION_FILE_PATH = os.path.join(CONFIG_DIRECTORY, 'session.json')
-STYLE_SHEET_PATH = os.path.join(CONFIG_DIRECTORY, 'style/safeeyes_style.css')
+STYLE_SHEET_PATH = os.path.join(STYLE_SHEET_DIRECTORY, 'safeeyes_style.css')
 SYSTEM_CONFIG_FILE_PATH = os.path.join(BIN_DIRECTORY, "config/safeeyes.json")
 SYSTEM_STYLE_SHEET_PATH = os.path.join(
     BIN_DIRECTORY, "config/style/safeeyes_style.css")
@@ -62,7 +62,7 @@ LOG_FILE_PATH = os.path.join(HOME_DIRECTORY, 'safeeyes.log')
 SYSTEM_PLUGINS_DIR = os.path.join(BIN_DIRECTORY, 'plugins')
 USER_PLUGINS_DIR = os.path.join(CONFIG_DIRECTORY, 'plugins')
 LOCALE_PATH = os.path.join(BIN_DIRECTORY, 'config/locale')
-SYSTEM_DESKTOP_FILE = os.path.join(BIN_DIRECTORY, "platform/safeeyes.desktop")
+SYSTEM_DESKTOP_FILE = os.path.join(BIN_DIRECTORY, "platform/io.github.slgobinath.SafeEyes.desktop")
 SYSTEM_ICONS = os.path.join(BIN_DIRECTORY, "platform/icons")
 DESKTOP_ENVIRONMENT = None
 IS_WAYLAND = False
@@ -94,28 +94,16 @@ def start_thread(target_function, **args):
     thread.start()
 
 
-# def execute_main_thread(target_function, args=None):
+# def execute_main_thread(target_function, *args, **kwargs):
 #     """
-#     Execute the given function in main thread.
+#     Execute the given function in main thread, forwarding positional and keyword arguments.
 #     """
-#     if args:
-#         GLib.idle_add(lambda: target_function(args))
-#     else:
-#         GLib.idle_add(target_function)
 
-def execute_main_thread(target_function, arg1=None, arg2=None):
+def execute_main_thread(target_function, *args, **kwargs):
     """
     Execute the given function in main thread.
     """
-    if arg1 is not None and arg2 is not None:
-        GLib.idle_add(lambda: target_function(arg1, arg2))
-    elif arg1 is not None:
-        GLib.idle_add(lambda: target_function(arg1))
-    elif arg2 is not None:
-        GLib.idle_add(lambda: target_function(arg2))
-    else:
-        GLib.idle_add(target_function)
-
+    GLib.idle_add(lambda: target_function(*args, **kwargs))
 
 def system_locale(category=locale.LC_MESSAGES):
     """
@@ -354,7 +342,7 @@ def module_exist(module):
     Check wther the given Python module exists or not.
     """
     try:
-        imp.find_module(module)
+        importlib.util.find_spec(module)
         return True
     except ImportError:
         return False
@@ -371,17 +359,15 @@ def merge_configs(new_config, old_config):
 
 def initialize_safeeyes():
     """
-    Create the config file and style sheet in ~/.config/safeeyes directory.
+    Create the config file and style sheet in XDG_CONFIG_HOME(or ~/.config)/safeeyes directory.
     """
-    logging.info('Copy the config files to ~/.config/safeeyes')
-
-    style_dir_path = os.path.join(HOME_DIRECTORY, '.config/safeeyes/style')
+    logging.info('Copy the config files to XDG_CONFIG_HOME(or ~/.config)/safeeyes')
     
     # Remove the ~/.config/safeeyes/safeeyes.json file
     delete(CONFIG_FILE_PATH)
 
-    # Create the ~/.config/safeeyes/style directory
-    mkdir(style_dir_path)
+    # Create the XDG_CONFIG_HOME(or ~/.config)/safeeyes/style directory
+    mkdir(STYLE_SHEET_DIRECTORY)
 
     # Copy the safeeyes.json
     shutil.copy2(SYSTEM_CONFIG_FILE_PATH, CONFIG_FILE_PATH)
@@ -392,27 +378,51 @@ def initialize_safeeyes():
         shutil.copy2(SYSTEM_STYLE_SHEET_PATH, STYLE_SHEET_PATH)
         os.chmod(STYLE_SHEET_PATH, 0o777)
 
-    create_startup_entry()
+    # initialize_safeeyes gets called when the configuration file is not present, which happens just after installation or manual deletion of .config/safeeyes/safeeyes.json file. In these cases, we want to force the creation of a startup entry
+    create_startup_entry(force=True)
 
-
-def create_startup_entry():
+def create_startup_entry(force=False):
     """
     Create start up entry.
     """
     startup_dir_path = os.path.join(HOME_DIRECTORY, '.config/autostart')
-    startup_entry = os.path.join(startup_dir_path, 'safeeyes.desktop')
+    startup_entry = os.path.join(startup_dir_path, 'io.github.slgobinath.SafeEyes.desktop')
+    # until SafeEyes 2.1.5 the startup entry had another name
+    # https://github.com/slgobinath/SafeEyes/commit/684d16265a48794bb3fd670da67283fe4e2f591b#diff-0863348c2143a4928518a4d3661f150ba86d042bf5320b462ea2e960c36ed275L398 
+    obsolete_entry = os.path.join(startup_dir_path, 'safeeyes.desktop')
 
-    # Create the folder if not exist
-    mkdir(startup_dir_path)
+    create_link = False
 
-    # Remove existing files
-    delete(startup_entry)
+    if force:
+        # if force is True, just create the link
+        create_link = True
+    else:
+        # if force is False, we want to avoid creating the startup symlink if it was manually deleted by the user, we want to create it only if a broken one is found
+        if os.path.islink(startup_entry):
+            # if the link exists, check if it is broken
+            try:
+                os.stat(startup_entry)
+            except FileNotFoundError:
+                # a FileNotFoundError will get thrown if the startup symlink is broken
+                create_link = True 
 
-    # Create the new startup entry
-    try:
-        os.symlink(SYSTEM_DESKTOP_FILE, startup_entry)
-    except OSError:
-        logging.error("Failed to create startup entry at %s" % startup_entry)
+        if os.path.islink(obsolete_entry):
+            # if a link with the old naming exists, delete it and create a new one
+            create_link = True
+            delete(obsolete_entry)
+
+    if create_link:
+        # Create the folder if not exist
+        mkdir(startup_dir_path)
+
+        # Remove existing files
+        delete(startup_entry)
+
+        # Create the new startup entry
+        try:
+            os.symlink(SYSTEM_DESKTOP_FILE, startup_entry)
+        except OSError:
+            logging.error("Failed to create startup entry at %s" % startup_entry)
 
 
 def initialize_platform():
@@ -423,13 +433,13 @@ def initialize_platform():
 
     applications_dir_path = os.path.join(HOME_DIRECTORY, '.local/share/applications')
     icons_dir_path = os.path.join(HOME_DIRECTORY, '.local/share/icons')
-    desktop_entry = os.path.join(applications_dir_path, 'safeeyes.desktop')
+    desktop_entry = os.path.join(applications_dir_path, 'io.github.slgobinath.SafeEyes.desktop')
 
     # Create the folder if not exist
     mkdir(icons_dir_path)
 
     # Create a desktop entry
-    if not os.path.exists(os.path.join(sys.prefix, "share/applications/safeeyes.desktop")):
+    if not os.path.exists(os.path.join(sys.prefix, "share/applications/io.github.slgobinath.SafeEyes.desktop")):
         # Create the folder if not exist
         mkdir(applications_dir_path)
         
@@ -492,7 +502,7 @@ def replace_style_sheet():
     os.chmod(STYLE_SHEET_PATH, 0o777)
 
 
-def intialize_logging(debug):
+def initialize_logging(debug):
     """
     Initialize the logging framework using the Safe Eyes specific configurations.
     """
@@ -666,7 +676,7 @@ def has_method(module, method_name, no_of_args=0):
     Check whether the given function is defined in the module or not.
     """
     if hasattr(module, method_name):
-        if len(inspect.getargspec(getattr(module, method_name)).args) == no_of_args:
+        if len(inspect.getfullargspec(getattr(module, method_name)).args) == no_of_args:
             return True
     return False
 
